(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    define(factory)
  } else if (typeof exports === 'object') {
    module.exports = factory()
  } else {
    root.Swoon = factory()
  }

})(this, function() {
  var Swoon = {}

  /**
   * Default config
   *
   * container: contains all image togglers and image divs
   * rootElement: top element to hide
   * parentElement: elements in the parent of the link to hide
   * element: contains the image to show
   * selector: the class to identify image togglers
   * additional: other elements to hide
   */
  var Config = Swoon.config = {
    container:      'body',
    rootElement:    'main',
    parentElement:  '*',
    element:        'div.swoon-image',
    selector:       'a.swoon-link',
    additional:     ''
  }

  var SwoonTogglers = {}

  /**
   * Configure settings by passing in an object like {container: 'main'}
   */
  Swoon.configure = function(options) {
    for (var key in options) {
      Config[key] = options[key]
    }
    return this
  }

  /**
   * Reset all bindings
   */
  Swoon.bind = function () {
    if(typeof SwoonTogglers.off === 'function') SwoonTogglers.unbind()
    
    SwoonTogglers = $(Config.selector, Config.container)
    SwoonTogglers.bind('mouseover mouseout', Swoon.toggle)
  }

  /**
   * Toggle the actual image
   */
  Swoon.toggle = function (event) {
    var el = $(event.currentTarget)
    el.parent().siblings(Config.parentElement).andSelf()
      .add(Config.element + '[rel="' + el.data('image') + '"]')
      .add(Config.additional)
      .toggleClass('hidden')

    el.toggleClass('active')
  }

  return Swoon
})
